@@ -81,17 +81,17 @@ def test_data_module(config_filename):
         batch_size=config.process.batch_size,
         history_minutes=30,  #: Number of timesteps of history, not including t0.
         forecast_minutes=60,  #: Number of timesteps of forecast.
-        satellite_image_size_pixels=config.process.satellite_image_size_pixels,
-        nwp_image_size_pixels=config.process.nwp_image_size_pixels,
-        nwp_channels=config.process.nwp_channels,
-        sat_channels=config.process.sat_channels,  # reduced for test data
-        pv_power_filename=config.input_data.solar_pv_data_filename,
-        pv_metadata_filename=config.input_data.solar_pv_metadata_filename,
-        sat_filename=config.input_data.satellite_zarr_path,
-        nwp_base_path=config.input_data.nwp_zarr_path,
-        gsp_filename=config.input_data.gsp_zarr_path,
-        topographic_filename=config.input_data.topographic_filename,
-        sun_filename=config.input_data.sun_zarr_path,
+        satellite_image_size_pixels=config.input_data.satellite.satellite_image_size_pixels,
+        nwp_image_size_pixels=config.input_data.nwp.nwp_image_size_pixels,
+        nwp_channels=config.input_data.nwp.nwp_channels[0:1],
+        sat_channels=config.input_data.satellite.sat_channels,  # reduced for test data
+        pv_power_filename=config.input_data.pv.solar_pv_data_filename,
+        pv_metadata_filename=config.input_data.pv.solar_pv_metadata_filename,
+        sat_filename=config.input_data.satellite.satellite_zarr_path,
+        nwp_base_path=config.input_data.nwp.nwp_zarr_path,
+        gsp_filename=config.input_data.gsp.gsp_zarr_path,
+        topographic_filename=config.input_data.topographic.topographic_filename,
+        sun_filename=config.input_data.sun.sun_zarr_path,
         pin_memory=True,  #: Passed to DataLoader.
         num_workers=0,  #: Passed to DataLoader.
         prefetch_factor=8,  #: Passed to DataLoader.
@@ -135,17 +135,17 @@ def test_batch_to_batch_to_dataset():
         batch_size=config.process.batch_size,
         history_minutes=30,  #: Number of timesteps of history, not including t0.
         forecast_minutes=60,  #: Number of timesteps of forecast.
-        satellite_image_size_pixels=config.process.satellite_image_size_pixels,
-        nwp_image_size_pixels=config.process.nwp_image_size_pixels,
-        nwp_channels=config.process.nwp_channels[0:1],
-        sat_channels=config.process.sat_channels,  # reduced for test data
-        pv_power_filename=config.input_data.solar_pv_data_filename,
-        pv_metadata_filename=config.input_data.solar_pv_metadata_filename,
-        sat_filename=config.input_data.satellite_zarr_path,
-        nwp_base_path=config.input_data.nwp_zarr_path,
-        gsp_filename=config.input_data.gsp_zarr_path,
-        topographic_filename=config.input_data.topographic_filename,
-        sun_filename=config.input_data.sun_zarr_path,
+        satellite_image_size_pixels=config.input_data.satellite.satellite_image_size_pixels,
+        nwp_image_size_pixels=config.input_data.nwp.nwp_image_size_pixels,
+        nwp_channels=config.input_data.nwp.nwp_channels[0:1],
+        sat_channels=config.input_data.satellite.sat_channels,  # reduced for test data
+        pv_power_filename=config.input_data.pv.solar_pv_data_filename,
+        pv_metadata_filename=config.input_data.pv.solar_pv_metadata_filename,
+        sat_filename=config.input_data.satellite.satellite_zarr_path,
+        nwp_base_path=config.input_data.nwp.nwp_zarr_path,
+        gsp_filename=config.input_data.gsp.gsp_zarr_path,
+        topographic_filename=config.input_data.topographic.topographic_filename,
+        sun_filename=config.input_data.sun.sun_zarr_path,
         pin_memory=True,  #: Passed to DataLoader.
         num_workers=0,  #: Passed to DataLoader.
         prefetch_factor=8,  #: Passed to DataLoader.
